==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ForkJoinNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ForkJoinNode;
import io.ciera.tool.sql.ooaofooa.activity.ForkJoinNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class ForkJoinNodeSetImpl extends InstanceSet<ForkJoinNodeSet,ForkJoinNode> implements ForkJoinNodeSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ForkJoinNode forkjoinnode : this ) forkjoinnode.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ForkJoinNode forkjoinnode : this ) forkjoinnode.setDescrip( m_Descrip );
    }
    @Override
    public void setGuardCondition( String m_GuardCondition ) throws XtumlException {
        for ( ForkJoinNode forkjoinnode : this ) forkjoinnode.setGuardCondition( m_GuardCondition );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( ForkJoinNode forkjoinnode : this ) controlnodeset.add( forkjoinnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public ForkJoinNode nullElement() {
        return ForkJoinNodeImpl.EMPTY_FORKJOINNODE;
    }

    @Override
    public ForkJoinNodeSet emptySet() {
      return new ForkJoinNodeSetImpl();
    }

    @Override
    public ForkJoinNodeSet value() {
        return this;
    }

    @Override
    public List<ForkJoinNode> elements() {
        return Arrays.asList(toArray(new ForkJoinNode[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ForkJoinNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ForkJoinNode;
import io.ciera.tool.sql.ooaofooa.activity.ForkJoinNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ForkJoinNodeSetImpl extends InstanceSet<ForkJoinNodeSet,ForkJoinNode> implements ForkJoinNodeSet {

    public ForkJoinNodeSetImpl() {
    }

    public ForkJoinNodeSetImpl(Comparator<? super ForkJoinNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ForkJoinNode forkjoinnode : this ) forkjoinnode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ForkJoinNode forkjoinnode : this ) forkjoinnode.setId( ref_Id );
    }
    @Override
    public void setGuardCondition( String m_GuardCondition ) throws XtumlException {
        for ( ForkJoinNode forkjoinnode : this ) forkjoinnode.setGuardCondition( m_GuardCondition );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( ForkJoinNode forkjoinnode : this ) controlnodeset.add( forkjoinnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public ForkJoinNode nullElement() {
        return ForkJoinNodeImpl.EMPTY_FORKJOINNODE;
    }

    @Override
    public ForkJoinNodeSet emptySet() {
      return new ForkJoinNodeSetImpl();
    }

    @Override
    public ForkJoinNodeSet emptySet(Comparator<? super ForkJoinNode> comp) {
      return new ForkJoinNodeSetImpl(comp);
    }

    @Override
    public ForkJoinNodeSet value() {
        return this;
    }

    @Override
    public List<ForkJoinNode> elements() {
        return Arrays.asList(toArray(new ForkJoinNode[0]));
    }

}
